@@ -39,6 +39,7 @@ NetworkModelItem::NetworkModelItem(QObject *parent)
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
     , m_deviceState(NetworkManager::Device::UnknownState)
     , m_detailsValid(false)
+    , m_delayModelUpdates(false)
     , m_duplicate(false)
     , m_mode(NetworkManager::WirelessSetting::Infrastructure)
     , m_securityType(NetworkManager::NoneSecurity)
@@ -56,6 +57,7 @@ NetworkModelItem::NetworkModelItem(const NetworkModelItem *item, QObject *parent
     , m_connectionPath(item->connectionPath())
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
     , m_detailsValid(false)
+    , m_delayModelUpdates(item->delayModelUpdates())
     , m_duplicate(true)
     , m_mode(item->mode())
     , m_name(item->name())
@@ -490,6 +492,17 @@ void NetworkModelItem::setTxBytes(qulonglong bytes)
     }
 }
 
+bool NetworkModelItem::delayModelUpdates() const
+{
+    return m_delayModelUpdates;
+}
+
+void NetworkModelItem::setDelayModelUpdates(bool delay)
+{
+    // special case, does not need m_changedRoles
+    m_delayModelUpdates = delay;
+}
+
 bool NetworkModelItem::operator==(const NetworkModelItem *item) const
 {
     if (!item->uuid().isEmpty() && !uuid().isEmpty()) {
@@ -584,7 +597,7 @@ void NetworkModelItem::updateDetails() const
             if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
                 m_details << i18n("Connection speed") << UiUtils::connectionSpeed(wiredDevice->bitRate());
             }
-            m_details << i18n("MAC Address") << wiredDevice->permanentHardwareAddress();
+            m_details << i18n("MAC Address") << wiredDevice->hardwareAddress();
         }
     } else if (m_type == NetworkManager::ConnectionSettings::Wireless) {
         NetworkManager::WirelessDevice::Ptr wirelessDevice = device.objectCast<NetworkManager::WirelessDevice>();
@@ -602,7 +615,7 @@ void NetworkModelItem::updateDetails() const
                 m_details << i18n("Frequency") << UiUtils::wirelessFrequencyToString(accessPoint->frequency());
                 m_details << i18n("BSSID") << accessPoint->hardwareAddress();
             }
-            m_details << i18n("MAC Address") << wirelessDevice->permanentHardwareAddress();
+            m_details << i18n("MAC Address") << wirelessDevice->hardwareAddress();
         }
     } else if (m_type == NetworkManager::ConnectionSettings::Gsm || m_type == NetworkManager::ConnectionSettings::Cdma) {
 #if WITH_MODEMMANAGER_SUPPORT
